@@ -1,16 +1,16 @@
 package Search::OpenSearch::Response::Tiny;
-use Moose;
+use strict;
+use warnings;
 use Carp;
-extends 'Search::OpenSearch::Response::JSON';
+use base qw( Search::OpenSearch::Response::JSON );
 use JSON;
 
-our $VERSION = '0.399_05';
+our $VERSION = '0.21';
 
 my %tiny_fields = map { $_ => 1 } qw(
     total
     facets
     results
-    suggestions
     version
 );
 
@@ -53,7 +53,7 @@ Search::OpenSearch::Response::Tiny - provide minimal search results in JSON form
  );
  my $response = $engine->search(
     q   => 'quick brown fox',   # query
-    s   => 'score desc',        # sort order
+    s   => 'rank desc',         # sort order
     o   => 0,                   # offset
     p   => 25,                  # page size
     h   => 1,                   # highlight query terms in results
